@@ -7,8 +7,8 @@ use warnings;
 
 no warnings 'uninitialized';
 
-our $VERSION = '3.018'; # VERSION
-my $LAST_UPDATE = '3.011'; # manually update whenever code is changed
+our $VERSION = '3.020'; # VERSION
+my $LAST_UPDATE = '3.020'; # manually update whenever code is changed
 
 use Compress::Zlib;
 
@@ -16,7 +16,7 @@ use PDF::Builder::Basic::PDF::Utils;
 use PDF::Builder::Resource::XObject::Image::TIFF::File_GT;
 use PDF::Builder::Util;
 use Scalar::Util qw(weaken);
-use Graphics::TIFF ':all';  # have already confirmed that this exists
+use Graphics::TIFF 7 ':all';  # have already confirmed that this exists
 
 =head1 NAME
 
@@ -186,18 +186,14 @@ sub read_tiff {
     if ($tif->{'colorSpace'} eq 'Indexed') {
         my $dict = PDFDict();
         $pdf->new_obj($dict);
-        $self->colorspace(PDFArray(PDFName($tif->{'colorSpace'}), PDFName('DeviceRGB'), PDFNum(255), $dict));
+        $self->colorspace(PDFArray(PDFName($tif->{'colorSpace'}), PDFName('DeviceRGB'), PDFNum(2**$tif->{'bitsPerSample'}-1), $dict));
         $dict->{'Filter'} = PDFArray(PDFName('FlateDecode'));
-        $tif->{'fh'}->seek($tif->{'colorMapOffset'}, 0);
-        my $colormap;
-        my $straight;
-        $tif->{'fh'}->read($colormap, $tif->{'colorMapLength'});
+        my ($red, $green, $blue) = @{$tif->{'colorMap'}};
         $dict->{' stream'} = '';
-        $straight .= pack('C', ($_/256)) for unpack($tif->{'short'} . '*', $colormap);
-        foreach my $c (0 .. (($tif->{'colorMapSamples'}/3)-1)) {
-            $dict->{' stream'} .= substr($straight, $c, 1);
-            $dict->{' stream'} .= substr($straight, $c + ($tif->{'colorMapSamples'}/3), 1);
-            $dict->{' stream'} .= substr($straight, $c + ($tif->{'colorMapSamples'}/3)*2, 1);
+        for my $i (0 .. $#{$red}) {
+            $dict->{' stream'} .= pack('C', ($red->[$i]/256));
+            $dict->{' stream'} .= pack('C', ($green->[$i]/256));
+            $dict->{' stream'} .= pack('C', ($blue->[$i]/256));
         }
     } else {
         $self->colorspace($tif->{'colorSpace'});
